@@ -2,13 +2,12 @@ import math
 from copy import deepcopy
 from enum import Enum
 
-import pandas
-
 from pm4py.objects.conversion.log import constants
 from pm4py.objects.log import log as log_instance
 from pm4py.objects.log.log import EventLog, Event
 from pm4py.util import constants as pmutil
 from pm4py.util import exec_utils, pandas_utils
+import pkgutil
 
 
 class Parameters(Enum):
@@ -32,6 +31,8 @@ def __postprocess_stream(list_events):
     list_events
         Postprocessed stream
     """
+    import pandas
+
     for event in list_events:
         event_keys = list(event.keys())
         for k in event_keys:
@@ -75,13 +76,15 @@ def apply(log, parameters=None):
     case_pref = exec_utils.get_param_value(Parameters.CASE_ATTRIBUTE_PREFIX, parameters, 'case:')
     enable_deepcopy = exec_utils.get_param_value(Parameters.DEEP_COPY, parameters, False)
 
-    if isinstance(log, pandas.core.frame.DataFrame):
-        list_events = pandas_utils.to_dict_records(log)
-        if stream_post_processing:
-            list_events = __postprocess_stream(list_events)
-        for i in range(len(list_events)):
-            list_events[i] = Event(list_events[i])
-        log = log_instance.EventStream(list_events, attributes={'origin': 'csv'})
+    if pkgutil.find_loader("pandas"):
+        import pandas
+        if isinstance(log, pandas.core.frame.DataFrame):
+            list_events = pandas_utils.to_dict_records(log)
+            if stream_post_processing:
+                list_events = __postprocess_stream(list_events)
+            for i in range(len(list_events)):
+                list_events[i] = Event(list_events[i])
+            log = log_instance.EventStream(list_events, attributes={'origin': 'csv'})
     if isinstance(log, EventLog):
         return __transform_event_log_to_event_stream(log, include_case_attributes=True,
                                                      case_attribute_prefix=case_pref, enable_deepcopy=enable_deepcopy)
