@@ -1,6 +1,7 @@
 import shutil
 
-from pm4py.util.vis_utils import human_readable_stat, get_arc_penwidth, get_trans_freq_color, get_base64_from_gviz, get_base64_from_file
+from pm4py.util.vis_utils import human_readable_stat, get_arc_penwidth, get_trans_freq_color, get_base64_from_gviz, \
+    get_base64_from_file
 
 
 def save(gviz, output_file_path):
@@ -17,6 +18,7 @@ def save(gviz, output_file_path):
     render = gviz.render(cleanup=True)
     shutil.copyfile(render, output_file_path)
 
+
 def view(gviz):
     """
     View the diagram
